@@ -6,6 +6,7 @@ test_that("records field list returns", {
 
   expect_that(f, is_a("list"))
   expect_that(f[["data"]], is_a("list"))
+  expect_that(f[["indexData"]], is_a("list"))
   expect_that(f[["uuid"]][["type"]] == "string", is_true())
 })
 
@@ -14,6 +15,7 @@ test_that("records indexed subset returns", {
   f <- idig_meta_fields(subset="indexed")
   
   expect_that(f[["data"]], is_null())
+  expect_that(f[["indexData"]], is_null())
   expect_that(f[["uuid"]][["type"]] == "string", is_true())
 })
 
@@ -31,6 +33,7 @@ test_that("media list returns", {
 
   expect_that(f, is_a("list"))
   expect_that(f[["data"]], is_a("list"))
+  expect_that(f[["indexData"]], is_a("list"))
   expect_that(f[["uuid"]][["type"]] == "string", is_true())
 })
 
@@ -39,6 +42,7 @@ test_that("media indexed subset returns", {
   f <- idig_meta_fields(type="media", subset="indexed")
   
   expect_that(f[["data"]], is_null())
+  expect_that(f[["indexData"]], is_null())
   expect_that(f[["uuid"]][["type"]] == "string", is_true())
 })
 
